
McAfee SIEM API Wrapper: MFE_SAW
=================================
MFE_SAW is a wrapper around the McAfee ESM API versions 10.x and above.


Getting Started

.. toctree::
  :maxdepth: 2

  readme
  installation
  cli
  api

